      program odeint
!
      use nrtype
      use coeffs
!
      implicit none
!
      integer(I4B) :: i,j,it

      real(SP), dimension(nspec+1) :: y, dydt, yout
      !real(SP), dimension(nspec) :: y, dydt, yout
      real(SP), dimension(nspec) :: factor
      real(SP) :: t
      real(SP) :: deltat
      character*20 :: tag

      character*10 :: species
      character*75 :: files,filep,filecoef
      real*8      :: cstr(6),aerosolf


      INTERFACE
              SUBROUTINE derivs(x,y,dydx)
              use nrtype
              IMPLICIT NONE
              REAL(SP), INTENT(IN) :: x
              REAL(SP), DIMENSION(:), INTENT(IN) :: y
              REAL(SP), DIMENSION(:), INTENT(OUT) :: dydx
              END SUBROUTINE derivs
      END INTERFACE
!
      INTERFACE
              SUBROUTINE rk4(y,dydx,x,h,yout)
              use nrtype; USE nrutil, ONLY : assert_eq
              IMPLICIT NONE
              REAL(SP), INTENT(IN) :: x
              REAL(SP), INTENT(IN) :: h
              REAL(SP), DIMENSION(:), INTENT(IN) :: y
              REAL(SP), DIMENSION(:), INTENT(IN) :: dydx
              REAL(SP), DIMENSION(:), INTENT(OUT) :: yout
              INTERFACE
                     SUBROUTINE derivs(x,y,dydx)
                     use nrtype
                     IMPLICIT NONE
                     REAL(SP), INTENT(IN) :: x
                     REAL(SP), DIMENSION(:), INTENT(IN) :: y
                     REAL(SP), DIMENSION(:), INTENT(OUT) :: dydx
                     END SUBROUTINE derivs
              END INTERFACE
              END SUBROUTINE rk4
      END INTERFACE


      species="XYL" !"c12"
      tag="no6"

! -> factor correction for the partitioning 
      cstr(1)=1e4
      cstr(2)=1e2
      cstr(3)=1e1
      cstr(4)=1e0
      cstr(5)=1e-1
      cstr(6)=1e-3

      !cstr(1)=1e4
      !cstr(2)=1e2
      !cstr(3)=10**(0.5)
      !cstr(4)=10**(-0.5)
      !cstr(5)=10**(-1.5)
      !cstr(6)=1e-2


      do i=1,nspec
         factor(i) = (cstr(i) / (10.0+cstr(i)))   !OA=10ug/m3
         !factor(i) = (cstr(i) / (1.0+cstr(i)))
      end do
      print*,"COEFS: ",factor


! Modify if needed ------------------------------
      SELECT CASE (species)
      CASE ("ideal")    !8h rate cte for vbs species
            files = 'aer.ideal'
            filep = 'aer.precursor.ideal'
            OPEN(11,file=files,STATUS='NEW',FORM='FORMATTED')
            OPEN(31,file=filep,STATUS='NEW',FORM='FORMATTED')
            kp=1.e-11*2.e6
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
               !k(i)=1.0/(3600*8.0)*factor(i)
            end do
      CASE ("c12")
            kp=1.32*1.e-11*2.e6  !c12h26
            !k(1)=1.0/(3600*9.1)*factor(1)
            !k(2)=1.0/(3600*8.1)*factor(2)
            !k(3)=1.0/(3600*7.0)*factor(3)
            !k(4)=1.0/(3600*7.8)*factor(4)
            !k(5)=1.0/(3600*3.2)*factor(5)
            !k(6)=1.0/(3600*3.1)*factor(6)
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE ("C16")
            kp=1.96*1.e-11*2.e6  !c12h26
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE ("ALK4")
           kp=4.38132*1.e-12*2.e6  !c12h26
 !           kp=2.81*1.e-16*2.e6  !c12h26
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do
      CASE ("c18")
            kp=2.24*1.e-11*2.e6  !C08000
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do
      CASE ("c22")
            kp=2.81*1.e-11*2.e6  !C08000
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE ("TOL")
            kp=5.6*1.e-12*2.e6   !tol
            do i=1,nspec
               !k(i)=1.0/(3600*8.0)*factor(i)
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE ("XYL")
            kp=1.43*1.e-11*2.e6   !tol
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE ("API_OH")
            kp=5.22*1.e-11*2.e6  !apin
            !k(1)=1.0/(3600*34.0)*factor(1)
            !k(2)=1.0/(3600*19.0)*factor(2)
            !k(3)=1.0/(3600*10.0)*factor(3)
            !k(4)=1.0/(3600*10.0)*factor(4)
            !k(5)=1.0/(3600*5.0)*factor(5)
            !k(6)=1.0/(3600*6.0)*factor(6)

            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do
            k(6)=1.0/(3600*1.0)*factor(6)

      CASE ("lim")
            kp=1.64*1.e-10*2.e6
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE ("bpi")
!            k(1)=1.0/(3600*16.0)*factor(1)
!            k(2)=1.0/(3600*14.0)*factor(2)
!            k(3)=1.0/(3600*9.0)*factor(3)
!            k(4)=1.0/(3600*8.0)*factor(4)
!            k(5)=1.0/(3600*7.0)*factor(5)
!            k(6)=1.0/(3600*3.6)*factor(6)

            kp=7.43*1.e-11*2.e6
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE ("TERP_OH")
            !kp=5.2*1.e-11*2.e6  !apin
           kp=8.25672E-11*2.e6
            do i=1,nspec
               k(i)=2*1.e-11*2.e6*factor(i)
            end do
            !k(6)=1.0/(3600*0.2)*factor(6)
      CASE ("ISO_OH")
            kp=9.83e-11*2.e6
            !k(1)=1.0/(3600*8.)*factor(1)
            !k(2)=1.0/(3600*8.)*factor(2)
            !k(3)=1.0/(3600*6.)*factor(3)
            !k(4)=1.0/(3600*6.)*factor(4)
            !k(5)=1.0/(3600*6.)*factor(5)
            !k(6)=1.0/(3600*0.1)*factor(6)

            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE ("OLE1_OH")
            kp=3.22273e-11*2.e6
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do
      CASE ("OLE2_OH")
            kp=6.32303e-11*2.e6
            !kp=7.06e-11*2.e6
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do
      CASE ("benz")
            kp=1.217e-12*2.e6
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE DEFAULT
           kp=0.0
           k(:)=0.0
      END SELECT


! initialise aij coeficents 
! - for ideal case do it by hand below
! - for real case read it from output files

      SELECT CASE (species)
      CASE ("ideal")    !8h rate cte for vbs species

      ! Specify stoichiometric coefficients 
      a(1)=0.5
      a(2)=0.3
      a(3)=0.1
      a(4)=0.05
      a(5)=0.05
      a(6)=0.00
  
      b(:,:)=0. 
    
      b(1,1)=0.2
      b(2,1)=0.2
      b(3,1)=0.2
      b(4,1)=0.0
      b(5,1)=0.0
      b(6,1)=0.0

      b(1,2)=0.0 
      b(2,2)=0.0
      b(3,2)=0.2
      b(4,2)=0.2 
      b(5,2)=0.2 
      b(6,2)=0.0 
  
      b(1,3)=0.0
      b(2,3)=0.0
      b(3,3)=0.0
      b(4,3)=0.0
      b(5,3)=0.0
      b(6,3)=0.0
  
      b(1,4)=0.0
      b(2,4)=0.0
      b(3,4)=0.1
      b(4,4)=0.1
      b(5,4)=0.0
      b(6,4)=0.0
      
      b(1,5)=0.0
      b(2,5)=0.0
      b(3,5)=0.2
      b(4,5)=0.2
      b(5,5)=0.0
      b(6,5)=0.2
      
      b(1,6)=0.0
      b(2,6)=0.0
      b(3,6)=0.0
      b(4,6)=0.0
      b(5,6)=0.0
      b(6,6)=0.2
      
      print*,"VOC    VB1    VB2    VB3    VB4    VB5    VB6"    
      do i=1,nspec
         write(*,400) a(i),(b(j,i),j=1,nspec)
      enddo

      CASE DEFAULT
 
      a(:)=0.0
      b(:,:)=0.0

        !files to write the reconstructed output of the fit for various
        !species 
        files = 'fit6.' // trim(species)// '.0.1'//'.'//'no6'
        filep = 'fit6.precursor.' // trim(species)// '.0.1.no6'
        OPEN(11,file=files,STATUS='NEW',FORM='FORMATTED')
        OPEN(31,file=filep,STATUS='NEW',FORM='FORMATTED')

        !read the coefficents generated by the fit
        filecoef = '../DCDT_fit_realcase_blvs.tot.201411/FITS/fit6_coef.'//trim(species)// '.0.1.'//'no6'
        print*,"files: ",files
        print*,"files: ",filep
        print*,"filecoef: ",filecoef

        OPEN(41,file=filecoef,STATUS='OLD',FORM='FORMATTED')
           READ(41,*)
           READ(41,*)
        do i=1,nspec
           READ(41,400) a(i),(b(j,i),j=1,nspec)
           write(*,400) a(i),(b(j,i),j=1,nspec)
        enddo
        CLOSE(41)

400   format(8(1x,e10.3))

      END SELECT

! -> to get rid of some reactions eg. VB6+OH reactions just set kOH=0.0
      !k(1)=0.0 
      !k(2)=0.0 
      !k(3)=0.0 
      !k(4)=0.0 
      !k(5)=0.0 
      !k(6)=0.0 

      if(trim(tag).eq."static")then
        k(1)=0.0
        k(2)=0.0
        k(3)=0.0
        k(4)=0.0
        k(5)=0.0
        k(6)=0.0
      else if(trim(tag).eq."no56")then
        k(5)=0.0
        k(6)=0.0
      else if(trim(tag).eq."no6")then
        k(6)=0.0
      endif
      print*,"k per sec  ",k


!! Specify initial values
!      do i=1,nspec
!         y(i) = 0.0
!      enddo
! Specify initial values - if precursor is integrated too
      do i=2,nspec+1
         y(i) = 0.0
      enddo
      y(1)=conc_prec

! Specific output step size in seconds
      deltat = 300.0    !time step in gecko
!
      t=0.0
      aerosolf=0.0
!      write(11,200)t,(y(i),i=1,nspec),aerosolf*1.66E-12*250.0
!      write(31,100)t,conc_prec*exp(-kp*t)   !prcursor
      write(11,200)t,(y(i),i=2,nspec+1),aerosolf*1.66E-12*250.0
      write(31,100)t,y(1)

50   format(1x,f9.1,6(1x,1pe12.5))
100       format(2E24.14)
200      format(20E24.14)

      call derivs(t,y,dydt)
!
! Integrate for 3 days
      do it=1,ntime
         t=t+deltat
         call rk4(y,dydt,t,deltat,yout)

         aerosolf=0.0
         do i=1,nspec
            !aerosolf=aerosolf+y(i)*(1-factor(i)) !(1/(1+cstr(i)/1.)) !alma verifier
            aerosolf=aerosolf+y(i+1)*(1-factor(i)) !(1/(1+cstr(i)/1.)) !if precursor integrated 
         end do

         do i=1,nspec+1 !if precursor integrated
         !do i=1,nspec
            y(i)=yout(i)
         enddo
         call derivs(t,y,dydt)

!         write(11,200)t,(y(i),i=1,nspec),aerosolf*1.66E-12*250.0
!         write(31,100)t,conc_prec*exp(-kp*t)   !prcursor
         write(11,200)t,(y(i),i=2,nspec+1),aerosolf*1.66E-12*250.0
         write(31,100)t,y(1)
 
      enddo

      CLOSE(11)
      CLOSE(31)
      stop
      end
