; ***********************************************
; xy_2.ncl
;
; Concepts illustrated:
;   - Drawing an XY plot with multiple curves
;   - Changing the line color for multiple curves in an XY plot
;   - Changing the line thickness for multiple curves in an XY plot
;   - Drawing XY plot curves with both lines and markers
;   - Changing the default markers in an XY plot
;   - Making all curves in an XY plot solid
;
; ***********************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

;************************************************
begin


  taille     = 0.25
  first      = 0.25
  largeur    = 0.60


;************************************************
; read in data
;************************************************
  ncol = 2
  datap = readAsciiTable("aer.precursor.ideal", ncol, "float", 1)
  VOC           = datap(:,1) 

  ncol = 6
  data = readAsciiTable("aer.ideal", ncol, "float", 1)
  times         = data(:,0)
  VB1           = data(:,1)    ;logC* < -4
  VB2           = data(:,2)    ;logC* -4 and -3 
  VB3           = data(:,3)
  VB4           = data(:,4)
  VB5           = data(:,5)

  VB1@_FillValue = -999.
  VB2@_FillValue = -999.
  VB3@_FillValue = -999.
  VB4@_FillValue = -999.
  VB5@_FillValue = -999.
  VOC@_FillValue = -999.

;************************************************
; to plot multiple lines, you must put them into
; a mulidimensional array
;************************************************
 pdata      = new((/9,dimsizes(VB1)/),float)

 pdata(0,:) = VOC/10.
 pdata(1,:) = VB1
 pdata(2,:) = VB2
 pdata(3,:) = VB3
 pdata(4,:) = VB4
 pdata(5,:) = VB5
;************************************************
; plotting parameters
;************************************************
; wks   = gsn_open_wks ("x11","xy")                  ; open workstation
 wks   = gsn_open_wks ("ps","xy")                  ; open workstation

 res                   = True                      ; plot mods desired
 res@tiMainString      = "OA (gas+aer) mass (ug/m3) in various VBS bins"        ; add title

; note a similiar resource is xyLineThicknessF, which will effect all
; the lines in the array.
 res@xyLineThicknesses = (/4.,2.,2.,2.,2.,2.,2.,2.,2./)               ; make 2nd lines thicker

 res@xyLineColors      = (/"purple","blue","green","red","orange","brown","gray","black","yellow"/)          ; change line color

  res@vpXF              = 0.2
  res@vpYF              = (first+2*taille)+0.09*2
  res@vpWidthF          = largeur
  res@vpHeightF         = taille
  res@tmLabelAutoStride = True

 times@units = "seconds"
printVarSummary(times)
print(times)
 plot  = gsn_csm_xy (wks,times,pdata,res) ; create plot

end

