      program odeint
!

      use nrtype
      use coeffs
!
      implicit none
!
      integer(I4B) :: i,j,it

      real(SP), dimension(nspec+1) :: y, dydt, yout
      !real(SP), dimension(nspec) :: y, dydt, yout
      real(SP), dimension(nspec) :: factor
      real(SP) :: t
      real(SP) :: deltat
      character*20 :: tag

      character*10 :: species
      character*55 :: files,filep,filecoef
      real*8      :: cstr(6),aerosolf


      INTERFACE
              SUBROUTINE derivs(x,y,dydx)
              use nrtype
              IMPLICIT NONE
              REAL(SP), INTENT(IN) :: x
              REAL(SP), DIMENSION(:), INTENT(IN) :: y
              REAL(SP), DIMENSION(:), INTENT(OUT) :: dydx
              END SUBROUTINE derivs
      END INTERFACE
!
      INTERFACE
              SUBROUTINE rk4(y,dydx,x,h,yout)
              use nrtype; USE nrutil, ONLY : assert_eq
              IMPLICIT NONE
              REAL(SP), INTENT(IN) :: x
              REAL(SP), INTENT(IN) :: h
              REAL(SP), DIMENSION(:), INTENT(IN) :: y
              REAL(SP), DIMENSION(:), INTENT(IN) :: dydx
              REAL(SP), DIMENSION(:), INTENT(OUT) :: yout
              INTERFACE
                     SUBROUTINE derivs(x,y,dydx)
                     use nrtype
                     IMPLICIT NONE
                     REAL(SP), INTENT(IN) :: x
                     REAL(SP), DIMENSION(:), INTENT(IN) :: y
                     REAL(SP), DIMENSION(:), INTENT(OUT) :: dydx
                     END SUBROUTINE derivs
              END INTERFACE
              END SUBROUTINE rk4
      END INTERFACE


      species="_SPEC_" !"c12"
      tag="_TAG_"      !age or noage

! -> factor correction for the partitioning 
      cstr(1)=1e4
      cstr(2)=1e2
      cstr(3)=1e1
      cstr(4)=1e0
      cstr(5)=1e-1
      cstr(6)=1e-3


      do i=1,nspec
         !factor(i) = (cstr(i) / (1.0+cstr(i)))    !OA=1ug/m3
         factor(i) = (cstr(i) / (10.0+cstr(i)))    !OA=10ug/m3
      end do
      print*,"C*   : ",cstr
     ! print*,"   : ",(1/(1+cstr(:)/1.))
      print*,"COEFS: ",factor


! Modify if needed ------------------------------
      SELECT CASE (species)
      CASE ("TOL")
            kp=5.6*1.e-12*2.e6/4.
            !kp=5.6*1.e-12*2.e6   !REF_K tol
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("XYL")
            kp=1.43*1.e-11*2.e6/4.   
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do
      CASE ("aro2")
            kp=1.43*1.e-11*2.e6   
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("API_OH")
            kp=5.22*1.e-11*2.e6/2.  !apin kREF
            !kp=5.22*1.e-11*2.e6  !apin kREF
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("TERP_OH")
            !kp=5.22*1.e-11*2.e6/2.  !apin kREF
            kp=8.25672E-11*2.e6/5. 
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do

      CASE ("ISO_OH")
            kp=9.83e-11*2.e6/2.
            !kp=1.e-10*2.e6  !ref_k iso
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("OLE1_OH")
            kp=3.22273e-11*2.e6/4.5
            !kp=4.68e-11*2.e6  !ref_k
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("OLE2_OH")
            kp=6.32303e-11*2.e6/4.
            !kp=7.06e-11*2.e6 !ref_k
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do

      CASE ("c12")
            kp=1.32*1.e-11*2.e6/3.  !ref_k c12h26
            !kp=1.32*1.e-11*2.e6  !c12h26
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do

      CASE ("C16")
            kp=1.96*1.e-11*2.e6/3.  !ref_k c12h26
            !kp=1.32*1.e-11*2.e6  !c12h26
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do

 
      CASE ("ALK4")
            kp=4.38132*1.e-12*2.e6  !c12h26

!            kp=3.06*1.e-12*2.e6  !a guess
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do

      CASE ("ALK5")
            kp=1.324e-11*2.e6/3.  
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do


      CASE DEFAULT
           kp=0.0
           k(:)=0.0
      END SELECT

! output files

        !files to write the reconstructed output of the fit for various
        !species 
        files = 'gecs.'//trim(species)// '._NOX_'//'.'//'_TAG_'
        filep = 'gecs.precursor.' // trim(species)// '._NOX_._TAG_'
        OPEN(11,file=files,STATUS='NEW',FORM='FORMATTED')
        OPEN(31,file=filep,STATUS='NEW',FORM='FORMATTED')

        print*,"files: ",files
        print*,"files: ",filep

!--


! initialise aij coeficents 
! a(i) are from VOC+OH reaction
! b(ij) are from ageing reactions

!lownox: calculated values from gecko and converted for 250g/mol
      a(:)=0.0

      SELECT CASE (species)
      CASE ("TERP_OH")
      a(1)=0.0866  !0.135
      a(2)=0.0208 
      a(3)=0.0143
      a(4)=0.0168
      a(5)=0.2047
      a(6)=0.2125

      CASE ("API_OH") 
      a(1)=0.1046
      a(2)=0.0186
      a(3)=0.0137
      a(4)=0.0139
      a(5)=0.1542
      a(6)=0.1670

      CASE ("ISO_OH")    !8h rate cte for vbs species
      a(1)=0.0006/4. !/4.
      a(2)=0.0258/4. !/4.
      a(3)=0.014/4.  !/4.
      a(4)=0.009/4.  !/4.
      a(5)=0.014/4.  !/4.
      a(6)=0.057/4.  !/4.


      CASE ("TOL")    !8h rate cte for vbs species
      a(1)=0.1193
      a(2)=0.0106
      a(3)=0.0047
      a(4)=0.0006
      a(5)=0.0136
      a(6)=0.045

      CASE ("XYL")    !8h rate cte for vbs species
      a(1)=0.0645
      a(2)=0.0108
      a(3)=0.0004
      a(4)=0.0002
      a(5)=0.016
      a(6)=0.0392

      CASE ("c12")    !8h rate cte for vbs species
      a(1)=0.047
      a(2)=0.014
      a(3)=0.014
      a(4)=0.017
      a(5)=0.098
      a(6)=0.075

      CASE ("ALK4")    !8h rate cte for vbs species
      a(1)=0.017
      a(2)=0.0011
      a(3)=0.0005
      a(4)=0.0004
      a(5)=0.0011
      a(6)=0.0008

      CASE ("ALK5")    !8h rate cte for vbs species
      a(1)=0.0554
      a(2)=0.0092
      a(3)=0.0062
      a(4)=0.0042
      a(5)=0.0354
      a(6)=0.0409

      CASE ("OLE1_OH")    !8h rate cte for vbs species
      a(1)=0.03
      a(2)=0.0024
      a(3)=0.0016
      a(4)=0.001
      a(5)=0.0093
      a(6)=0.0103

      CASE ("OLE2_OH")    !8h rate cte for vbs species
      a(1)=0.0128
      a(2)=0.0008
      a(3)=0.0004
      a(4)=0.0002
      a(5)=0.0011
      a(6)=0.001


      END SELECT

! ageing

      SELECT CASE (tag)

      CASE ("static") 
      b(:,:)=0. 
      k(:)=0.0
      print*,"k per sec  ",k
      END SELECT
      
      print*,"VOC    VB1    VB2    VB3    VB4    VB5    VB6"    
      do i=1,nspec
         write(*,400) a(i),(b(j,i),j=1,nspec)
      enddo

400   format(8(1x,e10.3))


!! Specify initial values
!      do i=1,nspec
!         y(i) = 0.0
!      enddo
! Specify initial values
      do i=2,nspec+1
         y(i) = 0.0
      enddo
      y(1)=conc_prec


! Specific output step size in seconds
      deltat = 300.0 !time step in the outputs 600.0
!
      t=0.0
      aerosolf=0.0
!      write(11,200)t,(y(i),i=1,nspec),aerosolf*1.66E-12*250.0
!      write(31,100)t,conc_prec*exp(-kp*t)   !prcursor
      write(11,200)t,(y(i),i=2,nspec+1),aerosolf*1.66E-12*250.0
      write(31,100)t,y(1)

50   format(1x,f9.1,6(1x,1pe12.5))
100       format(2E14.4)
200      format(20E14.4)

      call derivs(t,y,dydt)

! Integrate for 3 days
      do it=1,ntime
         t=t+deltat
         call rk4(y,dydt,t,deltat,yout)

         aerosolf=0.0
         do i=1,nspec
            aerosolf=aerosolf+y(i+1)*(1-factor(i)) !(1/(1+cstr(i)/1.)) !alma verifier
            !aerosolf=aerosolf+y(i)*(1-factor(i)) !(1/(1+cstr(i)/1.))
         end do

         !do i=1,nspec
         do i=1,nspec+1
            y(i)=yout(i)
         enddo
         call derivs(t,y,dydt)
!         write(11,200)t,(y(i),i=1,nspec),aerosolf*1.66E-12*250.0
!         write(31,100)t,conc_prec*exp(-kp*t)   !prcursor

         write(11,200)t,(y(i),i=2,nspec+1),aerosolf*1.66E-12*250.0
         write(31,100)t,y(1)
      enddo

      CLOSE(11)
      CLOSE(31)
      stop
      end
