      program odeint
!
      use nrtype
      use coeffs
!
      implicit none
!
      integer(I4B) :: i,j,it

      real(SP), dimension(nspec+1) :: y, dydt, yout
      !real(SP), dimension(nspec) :: y, dydt, yout
      real(SP), dimension(nspec) :: factor
      real(SP) :: t
      real(SP) :: com
      real(SP) :: deltat
      character*20 :: tag

      character*10 :: species
      character*55 :: files,filep,filecoef
      real*8      :: cstr(4),aerosolf


      INTERFACE
              SUBROUTINE derivs(x,y,dydx)
              use nrtype
              IMPLICIT NONE
              REAL(SP), INTENT(IN) :: x
              REAL(SP), DIMENSION(:), INTENT(IN) :: y
              REAL(SP), DIMENSION(:), INTENT(OUT) :: dydx
              END SUBROUTINE derivs
      END INTERFACE
!
      INTERFACE
              SUBROUTINE rk4(y,dydx,x,h,yout)
              use nrtype; USE nrutil, ONLY : assert_eq
              IMPLICIT NONE
              REAL(SP), INTENT(IN) :: x
              REAL(SP), INTENT(IN) :: h
              REAL(SP), DIMENSION(:), INTENT(IN) :: y
              REAL(SP), DIMENSION(:), INTENT(IN) :: dydx
              REAL(SP), DIMENSION(:), INTENT(OUT) :: yout
              INTERFACE
                     SUBROUTINE derivs(x,y,dydx)
                     use nrtype
                     IMPLICIT NONE
                     REAL(SP), INTENT(IN) :: x
                     REAL(SP), DIMENSION(:), INTENT(IN) :: y
                     REAL(SP), DIMENSION(:), INTENT(OUT) :: dydx
                     END SUBROUTINE derivs
              END INTERFACE
              END SUBROUTINE rk4
      END INTERFACE


      species="_SPEC_" !"c12"
      tag="_TAG_"      !age or noage

! -> factor correction for the partitioning 
      cstr(1)=1e3
      cstr(2)=1e2
      cstr(3)=1e1
      cstr(4)=1e0
      !shifted... it is equivalent to use 1ug/m3 of seed, and shift the
      !C* by 100, than use 100ug/m3 of seed at the given C* by lane et
      !cstr(1)=1e1
      !cstr(2)=1e0
      !cstr(3)=1e-1
      !cstr(4)=1e-2


      com=10.0 !COM is the mass of absorbing aerosols
      do i=1,nspec
         factor(i) = (cstr(i) / (com+cstr(i)))    !using OM of 1ug/m3
      end do
      print*,"C*   : ",cstr
      print*,"   : ",(1/(1+cstr(:)/1.))
      print*,"COEFS: ",factor


! Modify if needed ------------------------------
      SELECT CASE (species)
      CASE ("TOL")
            kp=5.6*1.e-12*2.e6   !tol
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do

      CASE ("XYL")
            kp=1.43*1.e-11*2.e6   !tol
            do i=1,nspec
               k(i)=2.*1.e-11*2.e6*factor(i)
            end do

      CASE ("aro2")
            kp=1.43*1.e-11*2.e6   !tol
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do

      CASE ("API_OH")
            kp=5.22*1.e-11*2.e6  !apin
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("TERP_OH")
            !kp=5.22*1.e-11*2.e6  !apin
            kp=8.25672E-11*2.e6
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do

      CASE ("ISO_OH")
            kp=9.83e-11*2.e6
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("OLE1_OH")
             kp=3.22273e-11*2.e6
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("OLE2_OH")
            kp=6.32303e-11*2.e6
            !kp=7.06e-11*2.e6 !ref_k
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("ALK5")
            kp=1.32*1.e-11*2.e6  !c12h26
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do
      CASE ("ALK4")
            kp=4.38132*1.e-12*2.e6  !c12h26
!           kp=3.06*1.e-12*2.e6  !a guess
            do i=1,nspec
               k(i)=2.e-11*2.e6*factor(i)
            end do

      CASE DEFAULT
           kp=0.0
           k(:)=0.0
      END SELECT

! output files

        !files to write the reconstructed output of the fit for various
        !species 
        files = 'vbs.'//trim(species)// '._NOX_'//'.'//'_TAG_'
        filep = 'vbs.precursor.' // trim(species)// '._NOX_._TAG_'
        OPEN(11,file=files,STATUS='NEW',FORM='FORMATTED')
        OPEN(31,file=filep,STATUS='NEW',FORM='FORMATTED')

        print*,"files: ",files
        print*,"files: ",filep

!--


! initialise aij coeficents 
! a(i) are from VOC+OH reaction
! b(ij) are from ageing reactions

!lownox
! yields from Tsimpidi et al., 2010: need to ratio Mw_tsimpidi/250 and
! also devide by 1.5 density bc in gecko that is not accounted for

      a(:)=0.0

      SELECT CASE (species)

      CASE ("API_OH") 
      a(1)=0.600*180/250/1.5 
      a(2)=0.359*180/250/1.5
      a(3)=0.092*180/250/1.5
      a(4)=0.107*180/250/1.5

      CASE ("TERP_OH")    !8h rate cte for vbs species
      a(1)=0.600*180/250/1.5
      a(2)=0.359*180/250/1.5
      a(3)=0.092*180/250/1.5
      a(4)=0.107*180/250/1.5

      CASE ("TOL")    !8h rate cte for vbs species
      a(1)=0.525*150/250/1.5
      a(2)=0.375*150/250/1.5
      a(3)=0.225*150/250/1.5
      a(4)=0.075*150/250/1.5

      CASE ("XYL") !aro2   !8h rate cte for vbs species
      a(1)=0.525*150/250/1.5
      a(2)=0.375*150/250/1.5
      a(3)=0.300*150/250/1.5
      a(4)=0.075*150/250/1.5

      CASE ("ISO_OH")    !8h rate cte for vbs species
      a(1)=0.009*136/250/1.5
      a(2)=0.030*136/250/1.5
      a(3)=0.015*136/250/1.5
      a(4)=0.000*136/250/1.5

      CASE ("OLE1_OH")    !8h rate cte for vbs species
      a(1)=0.225*120/250/1.5
      a(2)=0.060*120/250/1.5
      a(3)=0.009*120/250/1.5
      a(4)=0.005*120/250/1.5

      CASE ("OLE2_OH")    !8h rate cte for vbs species
      a(1)=0.375*120/250/1.5
      a(2)=0.129*120/250/1.5
      a(3)=0.044*120/250/1.5
      a(4)=0.023*120/250/1.5

      CASE ("ALK5") !alk5   !8h rate cte for vbs species
      a(1)=0.000*150/250/1.5
      a(2)=0.000*150/250/1.5
      a(3)=0.300*150/250/1.5
      a(4)=0.000*150/250/1.5

     CASE ("ALK4") !alk4   !8h rate cte for vbs species
      a(1)=0.000*120/250/1.5
      a(2)=0.000*120/250/1.5
      a(3)=0.075*120/250/1.5
      a(4)=0.000*120/250/1.5


      END SELECT

! ageing

      SELECT CASE (tag)

      CASE ("noage") 
      b(:,:)=0. 

      k(1)=0.0
      k(2)=0.0
      k(3)=0.0
      k(4)=0.0
      print*,"k per sec  ",k

      CASE ("age") 
      b(:,:)=0. 
      k(4)=0.0
    
      b(1,1)=0.0
      b(2,1)=0.0
      b(3,1)=0.0
      b(4,1)=0.0

      b(1,2)=1.0 !1.075 
      b(2,2)=0.0
      b(3,2)=0.0
      b(4,2)=0.0 
  
      b(1,3)=0.0
      b(2,3)=1.0 !1.075
      b(3,3)=0.0
      b(4,3)=0.0
  
      b(1,4)=0.0
      b(2,4)=0.0
      b(3,4)=1.0 !1.075
      b(4,4)=0.0
      
      END SELECT
      
      print*,"VOC    VB1    VB2    VB3    VB4    VB5    VB6"    
      do i=1,nspec
         write(*,400) a(i),(b(j,i),j=1,nspec)
      enddo

400   format(8(1x,e10.3))


!! Specify initial values
!      do i=1,nspec
!         y(i) = 0.0
!      enddo
! Specify initial values
      do i=2,nspec+1
         y(i) = 0.0
      enddo
      y(1)=conc_prec

! Specific output step size in seconds
      deltat = 300.0 !time step in the outputs 600.0
!
      t=0.0
      aerosolf=0.0
!      write(11,200)t,(y(i),i=1,nspec),aerosolf*1.66E-12*250.0
!      write(31,100)t,conc_prec*exp(-kp*t)   !prcursor
      write(11,200)t,(y(i),i=2,nspec+1),aerosolf*1.66E-12*250.0
      write(31,100)t,y(1)

50   format(1x,f9.1,6(1x,1pe12.5))
100       format(2E14.4)
200      format(20E14.4)

      call derivs(t,y,dydt)

! Integrate for 3 days
      do it=1,ntime
         t=t+deltat
         call rk4(y,dydt,t,deltat,yout)

         aerosolf=0.0
         do i=1,nspec
            aerosolf=aerosolf+y(i+1)*(1-factor(i)) !(1/(1+cstr(i)/1.)) !alma verifier
            !aerosolf=aerosolf+y(i)*(1-factor(i)) !(1/(1+cstr(i)/1.)) !alma verifier
         end do

         do i=1,nspec+1
        ! do i=1,nspec
            y(i)=yout(i)
         enddo
         call derivs(t,y,dydt)
!         write(11,200)t,(y(i),i=1,nspec),aerosolf*1.66E-12*250.0
!         write(31,100)t,conc_prec*exp(-kp*t)   !prcursor

         write(11,200)t,(y(i),i=2,nspec+1),aerosolf*1.66E-12*250.0
         write(31,100)t,y(1)
      enddo

      CLOSE(11)
      CLOSE(31)
      stop
      end
