load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

begin

  wcStrt     = systemfunc("date") 

;==============================================================================;
; 1. Define Variables
;==============================================================================;
  ;-----------------------------------------------------------------------------
  ; 1.1 User arguments
  ;-----------------------------------------------------------------------------  
  name_station = ""

  var_to_plot = "SOA_conc" 
  name_plot="SOA"
  units="ng/m~S~3~E~"
  ;units="~F33~m~F21~g/m~S~3~E~"
  ymax = 3. ;2.4 ;0.5 ;1.0 ;0.25 ;1.5 ;3 ;1.2 ;4 ;18 ;0.7
  ;ymax = 0.003 ;18 ;0.7

  species="XYL" ;ISO_OH" ;"OLE2_OH" ;ISO_OH" ;"TERP_OH" ;"ALK4" ;"TOL" ;TERP_OH" ;"ole1" ;xyl" ;"ole1" ;ole2" ;"ole1" ;"iso" ;"c12" ;"tol" ;"api" ;"tol" ;"api"
  nox="0.1"
  nox_vbs="lownox"

  file_in1 = "../INPUTS_ODE/5days/"+nox+"_aer."+species+"/aer.msoast"     ; GECKO full simulation SOA mass ug/m3
  file_in2 = "outfiles/vbs."+species+"."+nox_vbs+".noage"             ; VBS Lane et al., 2008 no ageing
  file_in3 = "outfiles/vbs."+species+"."+nox_vbs+".age"               ;                       with ageing
  file_in4 = "outfiles/gecs."+species+"."+nox+".static"           ; GECKO static
  file_in5 = "../CREAT_COEFS_DCDT_FIT/outfiles/fit6."+species+"."+nox+".allgas" ;no6" ;allgas" ;no56"             ; GECKO fit


  type     = "ps"
  file_out = "compar_SOA_"+species+"."+nox

  ncol = 2
  data = readAsciiTable(file_in1, ncol, "float", 0)
  times1         = data(:,0)
  aer_gec       = data(:,1)
  aer_gec@_FillValue = -999.
  delete(data)

  ncol = 6
  data = readAsciiTable(file_in2, ncol, "float", 0)
  times         = data(:,0)
  aer_vbs     = data(:,5)
  aer_vbs@_FillValue = -999.
  delete(data)
printVarSummary(times)

  ncol = 6
  data = readAsciiTable(file_in3, ncol, "float", 0)
  times3         = data(:,0)
  aer_vbsage     = data(:,5)
  aer_vbsage@_FillValue = -999.
  delete(data)

  ncol = 8
  data = readAsciiTable(file_in4, ncol, "float", 0)
  times4         = data(:,0)
  aer_static    = data(:,7)
  aer_static@_FillValue = -999.
  delete(data)

  ;ncol = 2
  ncol = 8
  data = readAsciiTable(file_in5, ncol, "float", 0)
  times4         = data(:,0)
  ;aer_fit    = data(:,1)
  aer_fit    = data(:,7)
  aer_fit@_FillValue = -999.
  delete(data)

  ;-----------------------------------------------------------------------------
  ; 1.2 Parameters
  ;-----------------------------------------------------------------------------
    taille     = 0.25
    first      = 0.25
    largeur    = 0.65

  ;-----------------------------------------------------------------------------
  ; 1.2 Get the times
  ;-----------------------------------------------------------------------------
  times_hour = times/3600.
  indd = ind(floattoint(times_hour)%12.eq.0 .AND.times_hour.eq.floattoint(times_hour))
  indmn = ind(times_hour.eq.floattoint(times_hour))
  time_lab = sprinti("%0.2i",floattoint(times_hour))

  ;-----------------------------------------------------------------------------
  ; 1.3 Open the workstation and define a colormap and get data to plot
  ;-----------------------------------------------------------------------------       
  wks = gsn_open_wks(type,file_out)
  gsn_define_colormap(wks,"rainbow+white+gray")


  pdata      = new((/5,dimsizes(aer_gec)/),float)
printVarSummary(aer_vbs)
printVarSummary(aer_static)
printVarSummary(pdata)

  pdata(0,:) = aer_gec  *1000. 
  pdata(1,:) = aer_vbs  *1000.    
  pdata(2,:) = aer_vbsage  *1000.
  pdata(3,:) = aer_static  *1000. ; convert from ug/m3 to ng/m3
  pdata(4,:) = aer_fit  *1000. ; convert from ug/m3 to ng/m3


  ;-----------------------------------------------------------------------------
  ; 1.4 Define plot resources
  ;-----------------------------------------------------------------------------    
     res = True 

     res@xyMarkLineModes   = (/"Lines","Lines","Lines","Lines","Lines"/)
     res@xyMarkerColors     = (/"black","green","gray","orange","red"/);,"Blue","black","black"/)  ;Marron                  ; Marker color
     res@xyLineThicknessF   = (/5.,1.,1.,1.,1./)
     res@xyDashPatterns = (/0,16,16,2,2/)               ; Make curves all solid
     res@gsnPaperOrientation   = "portrait"
     res@xyLineColors      = (/"black","green","gray","red","cyan"/)
     res@tiXAxisOn      = True
     res@tmXBOn         = True
     res@tmXBLabelsOn   = True

     res@tmYLLabelsOn          = True
     res@tmYRLabelsOn          = True
     res@tiYAxisSide           ="Left"

     res@tiMainFontHeightF     = .02
     res@tiXAxisFontHeightF    = 0.02
     res@tiXAxisFontThicknessF = 0.01

     res@tiYAxisPosition       = "Center"
     res@tiYAxisFontHeightF    = 0.02
     res@tiYAxisFontThicknessF = 0.01

     res@tiXAxisString    = "Time (Hours)"   
     res@tmYROn              = True   
     res@tmXBOn              = True     
     res@tmXTOn              = False

     res@tmXBMode            = "Explicit"              ; explicit labels
     res@tmXBValues          = times(indd)
     res@tmXBLabels          = time_lab(indd);
     res@tmXBMinorValues     = times(indmn)
     ;res@trXMinF             = min(x_plot(1,:nb_t1-1))
     res@trXMaxF             = max(times) ;max(x_plot(1,:nb_t1-1))
     res@trYMaxF             = ymax ;18 ;25
     res@trYMinF             = 0
     res@tmXBLabelFontThicknessF = 0.01

     res@gsnDraw                   = False 
     res@gsnFrame                  = False          

     ;res@xyDashPattern = 0               ; Make curves all solid

     res@tiYAxisString = name_plot+" ("+units+" )" 

     res@vpXF              = 0.2
     res@vpYF              = (first+2*taille)+0.09*2
     res@vpWidthF          = largeur
     res@vpHeightF         = taille
     res@tmLabelAutoStride = True

     plot = gsn_csm_xy (wks,times,pdata,res)

 getvalues plot
   "tmYLLabelFontHeightF"   : fheight
   "tmXTValues"             : tmXTValues
   "tmYLValues"             : tmYLValues
 end getvalues

 nTx  = dimsizes(tmXTValues)
 nTy  = dimsizes(tmYLValues)


       graph_main_title = name_station
       txres               = True
       txres@txFontHeightF = 0.018
       txres@txFontColor = "black"
       gsn_text_ndc(wks,graph_main_title,.49,0.98,txres)

       lgres                    = True
       lgres@lgLineColors       = (/"black","green","red"/)
       lgres@lgLineThicknessF   = (/2,2,2/)
       lgres@vpWidthF           = 0.13
       lgres@vpHeightF          = 0.13 ;8 ;6
       lgres@txFontHeightF = 0.1
       lgres@lgPerimOn          = True
       lgres@lgDashIndexes      = (/0,0,0/)
       lgres@lgLineLabelStrings = (/"","",""/)
       lgres@lgPerimFillColor   = 0
       lgres@lgPerimFill        = 0

       ;gsn_legend_ndc(wks,3,var_to_plot,0.85,0.9,lgres)



draw(plot)
frame(wks)

;==============================================================================;
; 4. End of Script
;==============================================================================;    
  ;-----------------------------------------------------------------------------
  ; 4.1 Delete everything
  ;-----------------------------------------------------------------------------  

  print("")
  print("End of the plot")
  print("The plot file is "+file_out+"."+type)  
  print("")
  
  ;-----------------------------------------------------------------------------
  ; 4.2 Get the time used to process the file
  ;-----------------------------------------------------------------------------    
  wallClockElapseTime(wcStrt, "Plotting  "+file_out, 0)

end
