; ***********************************************
; xy_2.ncl
;
; Concepts illustrated:
;   - Drawing an XY plot with multiple curves
;   - Changing the line color for multiple curves in an XY plot
;   - Changing the line thickness for multiple curves in an XY plot
;   - Drawing XY plot curves with both lines and markers
;   - Changing the default markers in an XY plot
;   - Making all curves in an XY plot solid
;
; ***********************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

;************************************************
begin


  taille     = 0.25
  first      = 0.25
  largeur    = 0.60


;************************************************
; read in data
;************************************************

  ncol = 2
  datap = readAsciiTable("aer.precursor.ideal", ncol, "float", 1)
  VOC           = datap(:,1)


  ncol = 8
  data = readAsciiTable("aer.ideal", ncol, "float", 1)
  times         = data(:,0)
  VB1           = data(:,1)    ;logC* >8
  VB2           = data(:,2)    ;logC* 7-8
  VB3           = data(:,3)
  VB4           = data(:,4)
  VB5           = data(:,5)
  VB6           = data(:,6)
  VB7           = data(:,7)

  VB1@_FillValue = -999.
  VB2@_FillValue = -999.
  VB3@_FillValue = -999.
  VB4@_FillValue = -999.
  VB5@_FillValue = -999.
  VB6@_FillValue = -999.
  VB7@_FillValue = -999.

  times_hour = times/3600.
  indd = ind(floattoint(times_hour)%12.eq.0 .AND.times_hour.eq.floattoint(times_hour))
  indmn = ind(times_hour.eq.floattoint(times_hour))
  time_label = sprinti("%0.2i",floattoint(times_hour))


;************************************************
; to plot multiple lines, you must put them into
; a mulidimensional array
;************************************************
 pdata      = new((/8,dimsizes(VB1)/),float)



 pdata(0,:) = (VB1)/2   ;logC* >5
 pdata(1,:) = VB2           ;logC* 3->5  blue
 pdata(2,:) = VB3           ;logC* 1->3  cyan 
 pdata(3,:) = VB4               ;logC* 0->1  black
 pdata(4,:) = VB5    ;orange
 pdata(5,:) = VB6    ;brown
 pdata(6,:) = VB7
 pdata(7,:) = (VOC)/2.  ;precursor green

print(pdata(0,:)+" "+pdata(1,:))
;************************************************
; plotting parameters
;************************************************
; wks   = gsn_open_wks ("x11","xy")                  ; open workstation
 wks   = gsn_open_wks ("ps","xy")                  ; open workstation

 res                   = True                      ; plot mods desired
 res@tiMainString      = "OA (gas+aer) in various VBS bins"        ; add title
 ;res@tiMainString      = "OA (gas+aer) mass (ug/m3) in various VBS bins"        ; add title

; note a similiar resource is xyLineThicknessF, which will effect all
; the lines in the array.
 res@xyLineThicknesses = (/2.,2.,2.,2.,2.,2.,2.,2.,2.,3./)               ; make 2nd lines thicker
res@xyDashPatterns = (/0,0,0,0,0,0,0,0/)
 res@xyLineColors      = (/"purple","blue","cyan","black","orange","brown","red","green"/)          ; change line color

  res@vpXF              = 0.2
  res@vpYF              = (first+2*taille)+0.09*2
  res@vpWidthF          = largeur
  res@vpHeightF         = taille
  res@tmLabelAutoStride = True

     res@tiYAxisPosition       = "Center"
     res@tiYAxisFontHeightF    = 0.02
     res@tiYAxisFontThicknessF = 0.01

     res@tiXAxisString    = "Time (Hours)"
     res@tiYAxisString    = "OA (molecules/cm3)"
     res@tmYROn              = True
     res@tmXBOn              = True
     res@tmXTOn              = False

     res@tmXBMode            = "Explicit"              ; explicit labels
     res@tmXBValues          = times(indd)
     res@tmXBLabels          = time_label(indd);
     ;res@tmXBMinorValues     = times(indmn)
     res@trXMinF             = 0;min(x_plot(1,:nb_t1-1))
     res@trXMaxF             = 121*3600.;max(x_plot(1,:nb_t1-1))
     ;res@trYMaxF             = ymax ;18 ;25
     ;res@trYMinF             = 0
     res@tmXBLabelFontThicknessF = 0.01

     res@gsnDraw                   = False
     res@gsnFrame                  = False

 times@units = "seconds"
 plot  = gsn_csm_xy (wks,times,pdata,res) ; create plot

var_to_plot = (/"VB1(>5)/2  ","VB2(5->3)  ","VB3(3->1)  ","VB4(1->0)  ","VB5(0->-1) ","VB6(-1->-2)","VB7(<-2)   ","VOC/2      "/)
       lgres                    = True
       lgres@lgLineColors       = res@xyLineColors;(/"black","green","red"/)
       lgres@lgLineThicknessF   = (/2,2,2,2,2,2,2,2/)
       lgres@vpWidthF           = 0.16
       lgres@vpHeightF          = 0.2 ;8 ;6
       lgres@txFontHeightF      = 1.2;0.8
       lgres@txFontThicknessF   = 0.08
       lgres@lgPerimOn          = False
       lgres@lgDashIndexes      = (/0,0,0,0,0,0,0,0/)
       lgres@lgLineLabelStrings = (/"","","","","","","","",""/)
       lgres@lgPerimFillColor   = 0
       lgres@lgPerimFill        = 0

  ;     gsn_legend_ndc(wks,8,var_to_plot,0.85,0.9,lgres)

     txres                    = True                            
     txres@txFontHeightF      = 0.015;
     txres@txFontThicknessF   = 0.08
     txres@txJust             = "BottomLeft"
     text = new(8,graphic)
     colors = res@xyLineColors
     do ii = 0, 7
        txres@txFontColor = colors(ii)
        label = var_to_plot(ii)
        gsn_text_ndc(wks,label,0.85, 0.9-(0.03*ii), txres)
     end do

  draw(plot)
  frame(wks)

end

