; ***********************************************
; xy_2.ncl
;
; Concepts illustrated:
;   - Drawing an XY plot with multiple curves
;   - Changing the line color for multiple curves in an XY plot
;   - Changing the line thickness for multiple curves in an XY plot
;   - Drawing XY plot curves with both lines and markers
;   - Changing the default markers in an XY plot
;   - Making all curves in an XY plot solid
;
; ***********************************************
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"

;************************************************
begin


  taille     = 0.25
  first      = 0.25
  largeur    = 0.60


;************************************************
; read in data
;************************************************


  ncol = 15
  data = readAsciiTable("../INPUTS_ODE/5days/0.1_aer.ISO_OH/aer.koh_vbs", ncol, "float", 1)   ; almas files
  data2 = readAsciiTable("../INPUTS_ODE/5days/0.1_aer.ISO_OH/aer.cdis_all", ncol, "float", 2)    ;julia's files
  times         = data(:,0)
  VB1           = data(:,1)    ;logC* >8
  VB2           = data(:,2)    ;logC* 7-8
  VB3           = data(:,3)
  VB4           = data(:,4)
  VB5           = data(:,5)
  VB6           = data(:,6)
  VB7           = data(:,7)
  VB8           = data(:,8)
  VB9           = data(:,9)
  VB10           = data(:,10)
  VB11           = data(:,11)
  VB12           = data(:,12)
  VB13           = data(:,13)
  VB14           = data(:,14)   ;logC* <-4

  VB1@_FillValue = -999.
  VB2@_FillValue = -999.
  VB3@_FillValue = -999.
  VB4@_FillValue = -999.
  VB5@_FillValue = -999.
  VB6@_FillValue = -999.
  VB7@_FillValue = -999.
  VB8@_FillValue = -999.
  VB9@_FillValue = -999.
  VB10@_FillValue = -999.
  VB11@_FillValue = -999.
  VB12@_FillValue = -999.
  VB13@_FillValue = -999.
  VB14@_FillValue = -999.


 times_hour = times/3600.
  indd = ind(floattoint(times_hour)%12.eq.0 .AND.times_hour.eq.floattoint(times_hour))
  indmn = ind(times_hour.eq.floattoint(times_hour))
  time_label = sprinti("%0.2i",floattoint(times_hour))


  VVB1           = data2(:,1)    ;logC* >8
  VVB2           = data2(:,2)    ;logC* 7-8
  VVB3           = data2(:,3)
  VVB4           = data2(:,4)
  VVB5           = data2(:,5)
  VVB6           = data2(:,6)
  VVB7           = data2(:,7)
  VVB8           = data2(:,8)
  VVB9           = data2(:,9)
  VVB10           = data2(:,10)
  VVB11           = data2(:,11)
  VVB12           = data2(:,12)
  VVB13           = data2(:,13)
  VVB14           = data2(:,14)   ;logC* <-4


;************************************************
; to plot multiple lines, you must put them into
; a mulidimensional array
;************************************************
 pdata      = new((/6,dimsizes(VB1)/),float)

; pdata(0,:) = (VB1*VVB1+VB2*VVB2+VB3*VVB3+VB4*VVB4)/(VVB1+VVB2+VVB3+VVB4)   ;logC* >5
 pdata(0,:) = (VB5*VVB5+VB6*VVB6)/(VVB5+VVB6)           ;logC* 3->5  blue
 pdata(1,:) = (VB7*VVB7+VB8*VVB8)/(VVB7+VVB8)           ;logC* 1->3  cyan
 pdata(2,:) = VB9               ;logC* 0->1  black
 pdata(3,:) = VB10    ;orange
 pdata(4,:) = VB11    ;brown
 pdata(5,:) = (VB12*VVB12+VB13*VVB13+VB14*VVB14)/(VVB12+VVB13+VVB14)  ;logC* < -2


; convert into hours 1/kOH for OH=2e6 molec/cc
 pdata=1./(pdata*2e6)/3600.

; average values for each bin
 avgdata=dim_avg_n(pdata,1)
 print(avgdata)

; print(pdata(0,:)+" "+pdata(1,:)+" "+pdata(2,:)+" "+pdata(3,:)+" "+pdata(4,:)+" "+pdata(5,:)+" "+pdata(6,:))
;************************************************
; plotting parameters
;************************************************
; wks   = gsn_open_wks ("x11","xy")                  ; open workstation
 wks   = gsn_open_wks ("ps","xy")                  ; open workstation

 res                   = True                      ; plot mods desired
 res@tiMainString      = "kOH weighted by gas-phase conc in VBS"        ; add title

; note a similiar resource is xyLineThicknessF, which will effect all
; the lines in the array.
 res@xyLineThicknesses = (/2.,2.,2.,2.,2.,2.,2.,2.,3./)               ; make 2nd lines thicker
 res@xyDashPatterns = (/0,0,0,0,0,0,0/)
 res@xyLineColors      = (/"purple","blue","cyan","black","orange","red","green"/)          ; change line color


  res@vpXF              = 0.2
  res@vpYF              = (first+2*taille)+0.09*2
  res@vpWidthF          = largeur
  res@vpHeightF         = taille
  res@tmLabelAutoStride = True

     res@tiYAxisPosition       = "Center"
     res@tiYAxisFontHeightF    = 0.02
     res@tiYAxisFontThicknessF = 0.01

     res@tiXAxisString    = "Time (Hours)"
     res@tiYAxisString    = "Decay time (1/kOH)"
     res@tmYROn              = True
     res@tmXBOn              = True
     res@tmXTOn              = False

     res@tmXBMode            = "Explicit"              ; explicit labels
     res@tmXBValues          = times(indd)
     res@tmXBLabels          = time_label(indd);
     ;res@tmXBMinorValues     = times(indmn)
     res@trXMinF             = 0;min(x_plot(1,:nb_t1-1))
     res@trXMaxF             = 121*3600.;max(x_plot(1,:nb_t1-1))
     ;res@trYMaxF             = ymax ;18 ;25
     ;res@trYMinF             = 0
     res@tmXBLabelFontThicknessF = 0.01

     res@gsnDraw                   = False
     res@gsnFrame                  = False

 times@units = "seconds"
 plot  = gsn_csm_xy (wks,times,pdata,res) ; create plot

var_to_plot = (/"VB1(5->3)  ","VB2(3->1)  ","VB3(1->0)  ","VB4(0->-1) ","VB5(-1->-2)","VB6(<-2)   ","      "/)
       lgres                    = True
       lgres@lgLineColors       = res@xyLineColors;(/"black","green","red"/)
       lgres@lgLineThicknessF   = (/2,2,2,2,2,2,2,2/)
       lgres@vpWidthF           = 0.16
       lgres@vpHeightF          = 0.2 ;8 ;6
       lgres@txFontHeightF      = 1.2;0.8
       lgres@txFontThicknessF   = 0.08
       lgres@lgPerimOn          = False
       lgres@lgDashIndexes      = (/0,0,0,0,0,0,0,0/)
       lgres@lgLineLabelStrings = (/"","","","","","","","",""/)
       lgres@lgPerimFillColor   = 0
       lgres@lgPerimFill        = 0

  ;     gsn_legend_ndc(wks,8,var_to_plot,0.85,0.9,lgres)

     txres                    = True
     txres@txFontHeightF      = 0.015;
     txres@txFontThicknessF   = 0.08
     txres@txJust             = "BottomLeft"
     text = new(8,graphic)
     colors = res@xyLineColors
     do ii = 0, 6
        txres@txFontColor = colors(ii)
        label = var_to_plot(ii)
        gsn_text_ndc(wks,label,0.85, 0.9-(0.03*ii), txres)
     end do

  draw(plot)
  frame(wks)


end

